@@ -5,7 +5,7 @@ use pyo3::prelude::*;
 
 /// Formats the sum of two numbers as string.
 #[pyfunction]
-fn resize(input_path: String, output_path: String, resize_to: f32) {
+fn resize(resize_to: f32, input_path: String, output_path: String) {
     resize_image(resize_to, input_path, output_path)
 }
 
