@@ -4,14 +4,14 @@ use image::imageops::FilterType;
 use image::{imageops, GenericImageView};
 use std::path::Path;
 
-pub fn resize_image(percentage: f32, input_path: String, output_path: String) {
+pub fn resize_image(resize_to: f32, input_path: String, output_path: String) {
     // Extract image and compute original dimensions.
     let mut image = image::open(&Path::new(&input_path)).unwrap();
     let image_diamensions = image.dimensions();
 
     // Compute output diamensions.
-    let width: f32 = image_diamensions.0 as f32 * percentage;
-    let height: f32 = image_diamensions.1 as f32 * percentage;
+    let width: f32 = image_diamensions.0 as f32 * resize_to;
+    let height: f32 = image_diamensions.1 as f32 * resize_to;
 
     // Resize and save.
     let resized_image =
